/**********************************************************************\
**
**                         Copyright (c) 2009-2020 by
**                          HENSGSTLER GmbH, Aldingen
**
**      This  software  is furnished under a licence and may be used and
**      copied only in accordance with the terms  of  such  licence  and
**      with the inclusion of the above copyright notice.  This software
**      or any other copies thereof may not  be  provided  or  otherwise
**      made  available  to any other person.  No title to and ownership
**      of the software is hereby transferred.
**
**      The  information  in  this software is subject to change without
**      notice and should not be construed as a commitment by Hengstler.
**
**  Module:      C56_Api_Test.c
**  Facility:    Hengstler C-56 Linux Printer Driver Package / S684019
**  Application: C-56 API test application for linux
**  Version:     R3-V1.04-FINAL - 2020FEB12
**  Environment: Linux Debian/Ubuntu/SUSE
**  Compiler:    gcc
**  Authors:     L. Tkac
**  Abstract:    Main file of the C-56 API test
**  History:     R3-V1.02f  / 2015NOV10 / TKA / Initial version
**
\**********************************************************************/

/*
** INCLUDES
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "../../Libraries/C56_Api.h"

   int main (int argc, char *argv[])
   {  
      intptr_t        iPrinter        =0;
      int             iWritenData     =0;      
      unsigned char   cmd_FormFeed[]  = {0x0C};                       // Form feed
      char            *printer_name     = NULL;		
	
      if (argc < 2){
        
        printf("\nERROR: No printer path available , example usage : C56_Api_Test \"/dev/bus/usb/001/011\" \n\n");
        
        goto EXIT;
      } 
      
      //-- Debug message         
      printf ("\n-------------------------------------------------\n");      
      printf ("--- START OF APPLICATION (%s)\n",argv[0]);
      printf ("-------------------------------------------------\n");         
      
      //-- Copy printer name
      //memcpy(printer_name,argv[1], strlen(argv[1]) );
      //printer_name[strlen(argv[1])] = '\0';
      //-- Allocate and Copy printer name
      printer_name = (char *) malloc (sizeof(char) * (strlen(argv[1]) +1 ));
      if(printer_name!= NULL){
         
	//-- Copy printer name    
         memcpy(printer_name, argv[1], strlen(argv[1]) );
         printer_name[strlen(argv[1])] = '\0';
         
      }else {
         
         //-- Debug message         
         printf ("--- ERROR: COULD NOT ALLOCATE MEMORY !\n");
         
         //-- Stop application
         goto EXIT; 
      }
      
      
      // only for debug
      //printf ("%s \n",printer_name);      

      //-- Open printer connection
      iPrinter = C56_api_printer_open(&printer_name[0]);
         
      //-- Debug message      
      printf ("\n-------------------------------------------------\n");      
      printf ("--- Printer name \t= %s\n--- Printer handler \t= %ld\n",argv[1],iPrinter);      
      printf ("-------------------------------------------------\n");  
      
      //-- Check if printer was opened  and set page length 
      if ( iPrinter >=0 )	
      {            
         //-- Clear pending data
         C56_api_printer_clear (iPrinter);
         
         //-- Write cmd to printer
         if ((iWritenData = C56_api_printer_write(iPrinter, cmd_FormFeed, sizeof(cmd_FormFeed), 1000)) != sizeof(cmd_FormFeed)){
            //-- Debug message         
            printf ("--- ERROR: COULD NOT SENT FORM FEED CMD !\n");                                       
            
            //-- Stop application
            goto EXIT;
         } else 
            //-- Debug message         
            printf ("--- FORM FEED CMD SENT OK\n");                                       
                                                     
         
         //-- Debug message                  
         printf ("-------------------------------------------------\n");      
         
         //-- Close printer
         C56_api_printer_close(iPrinter);
         iPrinter =0;
         
      }else {
         //-- Debug message         
         printf ("--- ERROR: OPENING PRINTER = %s \n",argv[1]);                                       
         
         //-- Stop application
         goto EXIT;         
      }      
      
      //-- Debug message  
      printf ("\n-------------------------------------------------\n");            
      printf ("--- END OF APPLICATION (%s)\n",argv[0]);
      printf ("-------------------------------------------------\n");      
      
EXIT :
      
      //-- Free memory
      if(printer_name!= NULL)
         free(printer_name);
      printer_name = NULL;

      //-- Close printer
      if(iPrinter != 0)
         C56_api_printer_close(iPrinter);      
      
      return 0;      
      
   } 
